Authors
=======
Steven Murray: `@steven-murray <https://github.com/steven-murray>`_

Contributors
------------

Comments, corrections and suggestions
-------------------------------------
* Chris Power (UWA)
* Aaron Robotham (UWA): `@asgr <https://github.com/asgr>`_
* Laura Wolz (UManchester)
